Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(146)

Unified Diff: pkg/polymer/lib/src/build/messages.dart

Issue 723393003: update to polymer js 0.5.1 (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: final tweaks Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/polymer/lib/src/build/messages.dart
diff --git a/pkg/polymer/lib/src/build/messages.dart b/pkg/polymer/lib/src/build/messages.dart
index 86335fdcafd88891ec2fe785c47c89933a6b3755..987bccd05dd146b7d6837e68297a2807397d5ba0 100644
--- a/pkg/polymer/lib/src/build/messages.dart
+++ b/pkg/polymer/lib/src/build/messages.dart
@@ -556,20 +556,19 @@ To do this, use the following pattern to update your pubspec.yaml:
If you would like to hide this warning and keep it inlined, do the same thing
but assign the value to true.
-'''
-);
+''');
const DART_SUPPORT_NO_LONGER_REQUIRED = const MessageTemplate(
const MessageId('polymer', 43),
'No need to include "dart_support.js" by hand anymore.',
- '"dart_support.js" not necessary',
+ '"dart_support.js" injected automatically',
'''
The script `packages/web_components/dart_support.js` is still used, but you no
longer need to put it in your application's entrypoint.
In the past this file served two purposes:
* to make dart2js work well with the platform polyfills, and
* to support registering Dart APIs for JavaScript custom elements.
Now, the code from `dart_support.js` is split in two halves. The half for
@@ -578,8 +577,7 @@ build`. The `web_components` package provides an HTML file containing the other
half. Developers of packages that wrap JavaScript custom elements (like
`core_elements` and `paper_elements`) will import that file directly, so
application developers don't have to worry about it anymore.
-'''
-);
+''');
const SCRIPT_INCLUDED_MORE_THAN_ONCE = const MessageTemplate(
const MessageId('polymer', 44),
@@ -603,3 +601,30 @@ And `foo.html` should look like:
<script type="application/dart" src="foo.dart"></script>
''');
+
+const WEB_COMPONENTS_NO_LONGER_REQUIRED = const MessageTemplate(
+ const MessageId('polymer', 45),
+ 'No need to include "webcomponents.js" by hand anymore.',
+ '"webcomponents.js" injected automatically',
+ '''
+The script `packages/web_components/webcomponents.js` is still used, but you no
+longer need to put it in your application's entrypoint.
+
+The polyfills provided by this file are no longer required in chrome and will
+automatically be added during `pub build` and `pub serve`.
+''');
+
+const PLATFORM_JS_RENAMED = const MessageTemplate(
+ const MessageId('polymer', 46),
+ '"platform.js" has been renamed to "webcomponents.js".',
+ '"platform.js" renamed to "webcomponents.js".',
+ '''
+The script `packages/web_components/platform.js` has been renamed to
+`packages/web_components/webcomponents.js`. This is automatically fixed in
+`pub serve` and `pub build` but we may remove this functionality in the next
+breaking version of Polymer.
+
+In addition, it is no longer required that you include this file directly, as
+`pub build` and `pub serve` will inject it for you, and its not required when
+running in dartium with a local server.
+''');

Powered by Google App Engine
This is Rietveld 408576698
@@ -556,20 +556,19 @@ To do this, use the following pattern to update your pubspec.yaml:
longer need to put it in your application's entrypoint.
In the past this file served two purposes:
- * to make dart2js work well with the platform polyfills, and
+ * to make dart2js work well with the web_components polyfills, and
* to support registering Dart APIs for JavaScript custom elements.
Now, the code from `dart_support.js` is split in two halves. The half for